@@ -1,3 +1,6 @@
+from typing import Type
+
+from pydantic import BaseModel
 from webexception.webexception import WebException
 
 
@@ -24,3 +27,10 @@ class AlreadyExists(BackendException):
 
     def __init__(self, uid: str) -> None:
         super().__init__(f"Entry with uid '{uid}' already exists.", uid=uid)
+
+
+class IndexNotExisting(BackendException):
+    status_code: int = 422
+
+    def __init__(self, model: Type[BaseModel], name: str) -> None:
+        super().__init__(f"No index named '{name}' existing for model '{model}'.", name=name)
